---
title: Sustainable Development
---

# 🌍 Overview 
Sustainable development and circularity are at the core of the **Natronaut mission**. Our goal is to **remediate nitrogen pollution** caused by agricultural runoff. We aim to not only treat the symptoms of this problem through **bioremediation** but also become part of the solution through the development of sustainable agricultural products and practices that benefit:

- Our oceans 
- Our livestock 
- Our communities
- Overall environmental health 

---

## 🎯 Sustainable Development Goals (SDGs)
The United Nations has established **17 Sustainable Development Goals (SDGs)** as part of the 2030 Agenda for Sustainable Development. These goals serve as a global call to action to **end poverty, protect the planet,** and **ensure peace and prosperity** for all. We have carried these values throughout our design process due to the inherently aligned nature of our project. As our SDG compass we first understood the SDGs, then defined our priority SDGs and finally set goals of how we would integrate them into our project. As such, we at Natronaut beleive that our mission aligns with the following SDGs:

## Bioremediation of Nitrates

### **💧 SDG 6: Clean Water and Sanitation**
> *Ensure availability and sustainable management of water and sanitation for all.*


Nitrogen pollution has become a very large problem in recent years. Nitrates in agricultural runoff lead to water contamination that affects both marine ecosystems and human health. Through **bioremediation, Natronaut focuses on removing these excess nitrates from water bodies, hence reducing the risks of waterborne diseases, toxin release and ensuring cleaner, safer water for both human and environmental needs.


Additionally, cleaner water bodies promote the overall health of aquatic ecosystems. These play a critical role in maintaining the water cycle and providing water that is sanitary in alignment with **SDG 6**.

### **🌊 SDG 14: Life Below Water**
> *Conserve and sustainably use the oceans, seas, and marine resources for sustainable development.*

Our **bioremediation efforts** focus on reducing nitrogen runoff from agriculture that causes **eutrophication**. Eutrophication is the excessive growth of algae in water bodies. Algal blooms lead to **hypoxic conditions** that harm marine life by creating "dead zones." This has devistating impacts on the marine food web as well as marine biodiversity. Additionally the decomposition of this algae leads to ocean acidification, thereby hindering marine life. Acidification can limit the ability of key marine organisms such as coral and shelfish from califying. By utilizing **V. natriegens** to assimilate nitrates, we actively prevent algal blooms, protecting marine biodiversity and ensuring healthier oceans and seas. This approach helps restore the balance in coastal ecosystems, making them more resilient against human impact.

#### Damage Caused by Eutrophication:

1. **Formation of Dead Zones**: Eutrophication stimulates excessive algal growth, consuming large amounts of oxygen when algae die and decompose. This process creates hypoxic areas (dead zones) and oceanic acidification where most marine life cannot survive. The Gulf of Mexico’s dead zone is one of the largest, severely affecting fish, shellfish, and other marine species.
   
2. **Loss of Marine Biodiversity**: Hypoxia kills many species, particularly those unable to move to other areas. Coral reefs, hosting 25% of all marine species, are especially vulnerable. The shift in species composition often favors organisms like jellyfish, making ecosystems less resilient and less productive.

3. **Harmful Algal Blooms (HABs)**: Certain algal blooms, like red tides, release toxins that damage marine and  human health.

4. **Loss of Healthy Ecosystem Services**: Eutrophicated waters lose their ability to provide nutrient cycling, water purification, and carbon sequestration. Additionally, coastal areas suffering from eutrophication lose their ability to buffer against storms and erosion, increasing their vulnerability.

By removing nitrates, we support safeguard marine habitats, and contribute to the long-term sustainability of marine ecosystems in conjustion with **SDG 14**. Our project is a key step toward preserving life below water for future generations and combating the global nitrogen crisis.

## Single Cell Proteiin Production

### ** 🍽️ SDG 2: Zero Hunger**
> *End hunger, achieve food security, improve nutrition, and promote sustainable agriculture.*

Our project directly supports food security and sustainable agriculture through the production of **single-cell proteins (SCPs)** from **V. natriegens**. SCPs not only serve as an sustainable feed alternative for livestock, but they can also be used as a direct nutritional supplement for humans. This makes them an essential tool in tackling issues related to food production, resource consumption, and malnutrition.

#### Boosting Livestock Quality:

1. **Improved Feed Quality**:
   - SCPs are packed with proteins, amino acids, and essential nutrients, offering a far more efficient feed alternative. This helps improve livestock growth and health, meaning farmers can produce more food from the same number of animals. Healthier animals lead to better quality byproducts which directly boosts both **food security** and **nutrition**.

2. **Efficiency in Resource Use**:
   - Unlike traditional fodder crops like soy, which need large amounts of resources like land, water, and fertilizers, SCPs can be produced in **controlled environments** with far fewer resources needed. By reducing the demand for land needed for to grow animal feed, we can free up agricultural space for food crops that can be consumed by humans. This would help reduce the competition between fodder and food production. This can also be very helpful for regions where agricultural land is limited or degraded, improving both food availability and accessibility.

3. **Climate Resilience**:
   - Additonaly due to their production in a controlled envionment SCP production isn’t as vulnerable to extreme weather events as traditional agriculture is. This means a **stable, continuous supply of high-quality feed**, even in regions hit by climate change or poor weather conditions. In turn, this helps ensure a more reliable food system.

#### Addressing Malnutrition:

1. **Nutrient-Rich Animal Products**:
   - Livestock fed with SCP-based diets produce more **nutrient-dense** meat, milk, and eggs. This can significantly help combat malnutrition in vulnerable communities by increasing access to high-protein, nutrient-packed food sources.

2. **Direct Human Consumption of SCPs**:
   - Additonally, SCPs can also be used as **nutritional supplements** for humans, especially in communities with limited access to high-quality protein sources. Since SCPs are rich in essential amino acids, vitamins, and minerals, they provide a crucial way to tackle **protein deficiencies** in under-resourced areas or dietary restriction, improving overall health outcomes.

By addressing the nutritional needs of both livestock and people, our project directly contributes to advancing **SDG 2**. SCPs provide a scalable, sustainable solution to boost livestock productivity, reduce resource competition, and improve access to vital nutrients, helping ensure we meet global food security goals.

### **🔄 SDG 12: Responsible Consumption and Production**
> *Ensure sustainable consumption and production patterns.*

The traditional linear economy follows a "take-make-dispose" model, which has lead to the overexploitation of resources and the accumulation of waste. In contrast, a **circular economy** is designed to minimize waste and make the most of resources by creating closed-loop systems to combat this issue. This approach encourages reusing, recycling, and regenerating materials to keep them in use for as long as possible. We wish to do this with nitrates. 

There are a few key factors to building a circular economy that are addressed through our innovative and circular solution:
- *Resource Efficiency*

- *Product Life Extension*

- *Recycling and Reuse*

- *Waste as a Resource*


Our mission embraces the principles of the circular economy by focusing on **bioremediation** and the development of **single-cell proteins** (SCPs):


- **Bioremediation:** By removing nitrates from agricultural runoff, we prevent pollution from entering natural water bodies, ensuring that these nutrients are recovered and redirected back into the production cycle rather than causing environmental harm. This reduces damage caused by synthetic fertilizers, which are often produced through resource-intensive processes, and contributes to a more sustainable and regenerative agricultural system.


- **Single-Cell Proteins (SCPs):** SCPs offer a sustainable alternative to conventional livestock feed, which often depends on large-scale monoculture crops like soy and corn. Producing SCPs requires less land, water, and energy, making them a more efficient and eco-friendly protein source. By integrating SCPs into the food system, we contribute to a **circular bioeconomy** where waste is minimized, and resources are continually reused and regenerated.


By applying circular economy principles, we aim to **close the loop** in the agricultural sector, reducing waste and promoting more sustainable consumption and production patterns in alignment with **SDG 12**. This shift not only helps reduce the environmental impact of agriculture but also supports the long-term viability of natural resources, ensuring that they can continue to sustain future generations. It is also a key factor that differenciates us from past nitrate bioremediation iGEM teams which typically release the nitrogen back into the atmosphere. Since the Haber-Bosch process accounts for 2% of the world's carbon emissions we believe that this resource intenively produced product should not be released and wasted and can be better used for SCPs so they continue to serve their intended communities. 

### **🌳 SDG 15: Life on Land**
> *Protect, restore, and promote sustainable use of terrestrial ecosystems.*

In addition to addressing marine ecosystems, our project contributes to the sustainable use of terrestrial ecosystems through the production of **single-cell proteins (SCPs)**. These SCPs, derived from **V. natriegens**, provide an eco-friendly and sustainable alternative to traditional protein sources for animal feed. By offering this innovative protein solution, we reduce the demand on agricultural systems that require extensive land, water, and resources. This reduction helps mitigate deforestation, habitat destruction, and biodiversity loss caused by livestock farming.

#### Why We Need to Improve Livestock Diets:

1. **Environmental Impact**:
   - **Land Use**: Conventional livestock feed like soy and corn requires large-scale monocultures, leading to deforestation and soil degradation. Deforestation in regions like the Amazon for soy plantations contributes to biodiversity loss.
   - **Water Use**: Growing feed crops requires vast amounts of water, with 1 kg of beef requiring approximately 15,000 liters of water. SCP production uses significantly less water and can help address water scarcity.
   - **Greenhouse Gas Emissions**: Livestock contributes heavily to methane emissions, and growing feed crops releases nitrous oxide through synthetic fertilizers. SCP production emits far fewer greenhouse gases, contributing to a lower carbon footprint.
   - **Nutrient Pollution**: Runoff from manure and fertilizers used in livestock farming leads to nutrient pollution, causing problems like eutrophication in water bodies.

2. **Nutritional Gaps**: Traditional livestock feed is often nutritionally imbalanced, which reduces animal productivity and increases emissions. SCPs, being rich in essential amino acids, vitamins, and minerals, offer a more balanced diet, improving animal health and efficiency.

#### Benefits of SCPs for Livestock Diets:

- **Resource Efficiency**: SCPs are produced using microorganisms, which can be grown in bioreactors, requiring minimal land and water. This efficiency helps preserve terrestrial ecosystems and reduce strain on natural resources.
  
- **Sustainability**: SCPs can be produced from waste streams or using methane or carbon dioxide, contributing to a circular economy. They offer a sustainable alternative to traditional livestock feeds, which often lead to environmental degradation.

- **Improved Livestock Health**: SCPs provide a complete nutritional profile, improving livestock growth and productivity, and reducing the environmental footprint of meat production.

- **Addressing the Nitrogen Crisis**: SCPs reduce the need for synthetic fertilizers and can be produced using nitrogen-fixing microorganisms, helping to address the nitrogen crisis in agriculture. This innovation supports sustainable farming practices, minimizing environmental damage while maintaining high yields.

Given the nitrogen crisis's significant impact on agriculture, we have consulted with industry experts to ensure our approach aligns with real-world needs for environment and agriculture. To do this we conducted an interview with **Umberto di Majo** from **Unimer**, a top Italian fertilizer manufacturer that prioritizes environmentally friendly formulations. From their approach we have learned how to further analyze and study the impact of novel technology introduction onto terrestrial environments. We learned that their organo-mineral fertilizers have been able to drastically reduce nitrogen runoff and better valorize applied nitrogen, resulting in far superior plant growth than traditional mineral fertilizers. This has been best visible in their long term studies. For our project this helped us understand better plan the types of studies we would do to prove the efficiency of our SCPs and their impacts on the animals and terrestrial ecosystems long term. 

Furthermore, through our discussions **di Majo** we were able to better understand the relationship and nuances  between the Nitrogen crisis, the terrestrial environment and farmers which helped us redirect our purpose as a project. This is further detailed on our human practices page. 

Through our project, we aim to foster a circular economy that benefits both land and marine environments while promoting more sustainable agricultural practices in alignment with **SDG 15**.

---
## 🌐 Virtual Sustainable Development Symposium
On September 12th we hosted a **Virtual Sustainable Developement Symposium** in which we further explored the link between the SDGs, synthetic biology and iGEM. This was done in order to highlight the role of sustainable developement oriented values in the future of genetic engineering. In doing so we brought together multiple contributing members, specfically iGEM teams, iGEM Ambassadors and researchers to promote the UN's 17 SDGs. In doing this we had 30 attendees at the event as well as over 500 views through promotional and educational material about the symposium and the SDGs themselves. 

![Virtual Sustainable Development Symposium](https://static.igem.wiki/teams/5306/virtualsdgattendees.png)


The opening presentation was done by iGEM ambassadors **Rashik Chand** (Asia & Oceania) and **Kate Willis-Urena** (Latin America) who spoke on what the 17 SDGs are and their role in iGEM. From this presentation attendees were able to understand the history and significane of the catagory as well as get additonal tips from the speakers. The second presentation was done by **Dr. Erik Steen-Redeker** specifically on his years long research in PET degredation with engineered Escheria coli. In this students were able to gain perspective on how SDGs drive research outside of iGEM and understand it's nuanances. In this we were also able to deeper explore the relationship between SDGs, research and society as Dr. Redeker claimed that "People are usually when they hear the word GMO however in my experiences I find when I explain my research and how we want to use GMOs to help the environment, it changes their attitudes towards them." The third speaker presentation was done by members of the iGEM Aachen 2023 team, **Frederik Kauẞmann** and **Melissa Lausberg**, who were nominated for the Sustainable Development Impact prize in their year. From them teams were able to learn their strategy for keeping sustainabilty at the core of their project, Rarecycle, which focused on recycling E-Waste with a fungal material equipt with metal binding peptides. They broke their plan down into 5 steps; 1: Asking yourself clarifying questions, 2: Choosing the right SDGs, 3: Building with research, 4: Consulting partners and experts and 5: Implement, learn and repeat. This provided the iGEM teams with a step by step plan to approach their project with the right SDGs in mind and growing with them. Each presentation also had a Q&A session.  All presentation slides can be found below for future teams to inform themselves with. 

<embed src="https://static.igem.wiki/teams/5306/introductiontoigem-sdgs-ambassadors.pdf" width="800px" height="600px" />

<embed src="https://static.igem.wiki/teams/5306/igemaachen2023-igemsdgsguide.pdf" width="800px" height="600px" />

The final segment of the virtual symposium was the pitch session in feedback was provided by iGEM Ambassador for Europe and past judge **Yassin Somoue Chafik**. In total there were 5 pitching teams including, **iGEM KU Leuven, iGEM REC-Chennai, iGEM AFCM Egypt, iGEM Bolivia and iGEM MSP-Maastricht**. In this time all teams could focus on pitching their project as well as their relation to the SDGs to gain feedback on their approach before the Grand Jamboree and Wiki freeze. 

## Exploring Circularity in Biotechnology Education: Insights from Dr. Luisa Bortesi 🌱🧬 ⚙️

As part of our commitment to sustainability and education, toward the **Best Sustainable Development** and **Best Education** special prizes, we engaged with experts in the field to discuss how **circularity** and **sustainability** can be integrated into biotechnology and education.

One insightful conversation was had with **Dr. Luisa Bortesi**, an associate professor of **Molecular and Applied Biotechnology** at Maastricht University (UM). From an educational perspective, Dr. Bortesi teaches biotechnology courses in the Bachelor’s programs of **Business Engineering** and **Circular Engineering** as well as in the **Master’s program of Biobased Materials**. Circularity and sustainability aspects are inherent in the environment in which Dr. Bortesi teaches, particularly with the latter programs. In addition to this, Dr. Bortesi has insight into the development and shaping of the **Biobased Materials Master program**, of which she is the Chair of the Educational Programme Committee. At the University, Dr. Bortesi leads a research group in Molecular and Applied Biotechnology at the **Aachen-Maastricht Institute for Biobased Materials**.

**Circularity** and **sustainability** are two closely related concepts, especially in the context of biotechnology. From an educational perspective, there are two main aspects to consider: the **content** and the **educational approach**. Within biotechnology, the link between the content and sustainability is more straightforward. Providing examples of how biotechnology tools and applications contribute to **sustainability goals** and the **circular economy** is crucial to inspire enthusiasm and show that an actual impact can be made.

When considering the educational approach, Dr. Bortesi stresses that fostering competencies such as **global thinking**, **problem-solving**, and a **long-term perspective** in students is a fundamental foundation. These skills are essential to ensure that individuals are aware of their actions and their impact on nature 🌍, while also equipping them with the ability to address complex challenges and create sustainable solutions for the future. Our goals for achieving the **SDGs** should be geared towards alignment of our actions with these natural systems, integrating **circular economy** principles into both biotechnology education and application.

### Understanding the Role of Biotechnology in Circularity 🔄

Dr. Bortesi emphasized that **circularity** and **sustainability** are inherently interconnected, and **biotechnology** has immense potential to contribute toward these goals. She highlighted one area of application that is in the **valorization of waste**. For example, a waste product in the food industry, usually disposed of at a cost, can be valorized into **high-value products**. Furthermore, exploiting biology in technical aspects can additionally add value to the processes while achieving a more sustainable approach. 

In Dr. Bortesi’s lab, **chitin** from crustacean shells was valorized into **soluble chitosan monomers**, which have **high-value applications** in the **biomedical field** due to their **antibacterial** and **antimicrobial properties**. Within the lab, this process is achieved using **enzymatic degradation**, a more sustainable approach to standard chemical processes which require a lot of solvents and are not as selective.

This approach exemplifies how biotechnology can promote **sustainable practices** and **resource efficiency**, directly contributing to several **UN Sustainable Development Goals (SDGs)**, including:

- **SDG 9**: Industry, Innovation, and Infrastructure 🏗️
- **SDG 12**: Responsible Consumption and Production ♻️

Despite this immense potential, Dr. Bortesi expressed that a **multi-disciplinary effort** is needed and that biotechnology applications cannot be a stand-alone action. Considering **SDG 2** of Zero Hunger 🍽️, biological tools can surely aid, but it is still essential for consumers to adopt **more sustainable consumption** and attitudes.

### Challenges and Opportunities in Biotechnology Education 📚

One commonly discussed challenge that was raised is the **sustainability of lab practices**, considering the large generation of waste due to the use of **disposable items**. While some of this waste is unavoidable, there is certainly room for improvement. As responsible scientists, we might tackle this by rethinking some of our practices and finding ways to reduce waste and recycle when possible without compromising results. This aligns with our team's efforts to implement **sustainable lab practices**, contributing to **SDG 13**: Climate Action 🌍.

### Integrating SDGs into Educational Practices 🎓

For Dr. Bortesi, **sustainability** and the **SDGs** are integral to her **educational practices**. In teaching, she encourages students to connect their projects with the **SDGs**, fostering a sense of responsibility and empowerment to create tangible impacts. She further believes in empowering students to choose topics that they are passionate about. Such freedom of choice motivates students to explore practical ways to make a difference and encourages **meaningful contributions** toward a global solution.

She mentions the **interdisciplinarity** that is embedded in the philosophy of teaching at UM, noting that this is already in the right direction to prepare students for thinking with a **more circular mindset**. Dr. Bortesi is passionate about the environment that she is in, detailing her excitement to pass along the tools necessary for students to put into practice all that they have learned. 

This educational approach supports both **SDG 4**: Quality Education 📘 and **SDG 12**: Responsible Consumption and Production.

### Integrating SDGs into Industrial Practices 🏭

Considering the implementation of **sustainability** and the **SDGs** in the **biotechnology industry**, commitment can vary. One should reflect on the efforts made in assessing industries, as **greenwashing** can be prevalent in companies simply ticking the right boxes to appear more sustainable. However, there is a genuine interest and shift within the sectors toward a **more sustainable future**. Particularly among the **new generations** and start-ups 🚀, despite sometimes a lack of tools for complete implementation, the intent is there. It should be noted that this shift is not trivial, particularly in **established companies**, and that such a significant change doesn’t occur overnight. Small intentions can make a large impact to start a broader transformation. Dr. Bortesi shared an inspiring example of such in which the small change of making **vegetarian food** the default option for conferences was implemented, instead requiring people to specifically request meat.

### Implications for Our Project 🚀

Our conversation with **Dr. Bortesi** reinforced the importance of aligning our project with the **SDGs** and integrating sustainability principles into both our research and educational outreach. By:

- Developing **innovative solutions** that address real-world sustainability challenges.
- Implementing **sustainable practices** within our lab and team activities.
- Engaging in **educational outreach** that fosters a two-way dialogue about synthetic biology and sustainability.

### Conclusion 🎯

Engaging with educators like **Dr. Bortesi** has provided valuable insights into the intersection of **biotechnology**, **education**, and **sustainability**. We are inspired to incorporate such insights into our project, aiming to not only develop **biotechnological solutions** but also to evaluate and minimize the environmental footprint of our lab practices. Furthermore, establishing a two-way dialogue to raise awareness of the importance of **circular economy** principles in biotechnology and to inspire future generations to think critically about the sustainability of their work.
